@@ -101,7 +101,7 @@ int main(int argc, char *argv[])
     string TableName = "testtable";
     if (argc > 2) TableName = argv[2];
 
-    transaction<> T(C, "test9");
+    work T(C, "test9");
 
     // Create table.  If the table already existed, better to fail now.
     T.exec(("CREATE TABLE " + TableName + "(content VARCHAR)").c_str());
