@@ -1,8 +1,8 @@
 #include <iostream>
 #include <sstream>
 
-#include <pqxx/all.h>
-#include <pqxx/largeobject.h>
+#include <pqxx/pqxx>
+
 
 using namespace PGSTD;
 using namespace pqxx;
@@ -128,8 +128,8 @@ int main(int, char *argv[])
 
     largeobject Obj;
 
-    C.Perform(WriteLargeObject(Obj));
-    C.Perform(DeleteLargeObject(Obj));
+    C.perform(WriteLargeObject(Obj));
+    C.perform(DeleteLargeObject(Obj));
   }
   catch (const sql_error &e)
   {
