@@ -23,7 +23,7 @@ int main(int, char *argv[])
 {
   try
   {
-    const string TestStr = "Nasty\n\030Test\n\t String\r\0 With Trailer";
+    const string TestStr = "Nasty\n\030Test\n\t String\r\0 With Trailer\\\\\0";
 
     connection C(argv[1]);
     work T(C, "test62");
@@ -65,6 +65,7 @@ int main(int, char *argv[])
     if (c != B.end())
       throw logic_error("end() of binary string not reached");
 
+#ifndef PQXX_WORKAROUND_VC7
     binarystring::const_reverse_iterator r;
     for (i=B.length(), r=B.rbegin(); i>0; --i, ++r)
     {
@@ -76,6 +77,7 @@ int main(int, char *argv[])
     }
     if (r != B.rend())
       throw logic_error("rend() of binary string not reached");
+#endif
 
     if (B.str() != TestStr)
       throw logic_error("Binary string got mangled: '" + B.str() + "'");
